@@ -123,7 +123,7 @@
 #' @importFrom utils View
 #' @export 
 
-BETS.search = function(description="*",src,periodicity,unit,code,start,view=TRUE,lang="en"){
+BETS.search = function(description="*",src,periodicity,unit,code,start,view=TRUE,lang="pt"){
   
   conn = connection()
   
