@@ -10,10 +10,11 @@
 
 draw.iie_br = function(){
   
-  iiebr = paste0(system.file(package="BETS"), "/incerteza_fgv.csv")
-  data <- read.csv2(iiebr, stringsAsFactors = F)
+  #iiebr = paste0(system.file(package="BETS"), "/incerteza_fgv.csv")
+  iiebr = BETS.get("ST_100.0")
+  #data <- read.csv2(iiebr, stringsAsFactors = F)
   
-  iiebr = ts(data[,2], start = c(2000,1), frequency = 12)
+  iiebr = ts(iiebr[,2], start = c(2000,1), frequency = 12)
   iiebr.ma = ma(iiebr,6)
   
   m <- list(
@@ -29,7 +30,7 @@ draw.iie_br = function(){
     yref = "y",
     showarrow = TRUE,
     arrowhead = 6,
-    ay = 40,
+    ay = 50,
     ax = 0,
     font = list(size = 22)
   )
